@@ -195,6 +195,7 @@ Chunk = nut_processor(itf.chunked)
 iterable >> Chunk(n)
 
 Split iterable in chunks of size n, where each chunk is also an iterator.
+see also GroupBySorted(), ChunkWhen(), ChunkBy()
 
 >>> for chunk in Range(5) >> Chunk(2):
 >>> ... print list(chunk)
@@ -203,7 +204,7 @@ Split iterable in chunks of size n, where each chunk is also an iterator.
 [4]
 
 :param iterable iterable: Any iterable, e.g. list, xrange, ...
-:param n: Chunk size
+:param int n: Chunk size
 :return: Chunked iterable
 :rtype: Iterator over iterators
 """
@@ -215,6 +216,7 @@ class ChunkWhen(Nut):
         iterable >> ChunkWhen(func)
 
         Chunk iterable and create new chunk every time func returns True.
+        see also GroupBySorted(), Chunk(), ChunkBy()
 
         >>> from nutsflow import Map, Join, Collect
         >>> func = lambda x: x == '|'
@@ -239,7 +241,30 @@ class ChunkWhen(Nut):
         :return: Iterator over chunks, where each chunk is an iterator itself.
         :rtype: iterator over iterators
         """
-        return iterable >> GroupBySorted(self._key, nokey=True)
+        return iterable >> ChunkBy(self._key)
+
+
+@nut_processor
+def ChunkBy(iterable, func):
+    """
+    iterable >> ChunkBy(func)
+
+    Chunk iterable and create chunk every time func changes its return value.
+    see also GroupBySorted(), Chunk(), ChunkWhen()
+
+    >>> [1,1, 2, 3,3,3] >> ChunkBy(lambda x: x) >> Map(list) >> Collect()
+    [[1, 1], [2], [3, 3, 3]]
+
+    >>> [1,1, 2, 3,3,3] >> ChunkBy(lambda x: x < 3) >> Map(list) >> Collect()
+    [[1, 1, 2], [3, 3, 3]]
+
+    :param iterable iterable: Any iterable, e.g. list, xrange, ...
+    :param function func: Functions the iterable is chunked by 
+    :return: Chunked iterable
+    :rtype: Iterator over iterators
+    """
+    groupiter = itt.groupby(iterable, func)
+    return itt.imap(lambda t: t[1], groupiter)
 
 
 Cycle = nut_processor(itt.cycle)
@@ -602,9 +627,10 @@ def GroupBy(iterable, keycol=lambda x: x, nokey=False):
     Note that elements of iterable do not need to be sorted.
     GroupBy will store all elements in memory!
     If the iterable is sorted use GroupBySorted() instead.
+    see also Chunk(), ChunkWhen(), ChunkBy()
 
     >>> from nutsflow import Collect
-    
+
     >>> [1, 2, 1, 1, 3] >> GroupBy() >> Collect()
     [(1, [1, 1, 1]), (2, [2]), (3, [3])]
 
@@ -614,6 +640,12 @@ def GroupBy(iterable, keycol=lambda x: x, nokey=False):
     >>> ['--', '+++', '**'] >> GroupBy(len) >> Collect()
     [(2, ['--', '**']), (3, ['+++'])]
 
+    >>> ['a3', 'b2', 'c1'] >> GroupBy(1) >> Collect()
+    [('1', ['c1']), ('3', ['a3']), ('2', ['b2'])]
+
+    >>> [(1,3), (2,2), (3,1)] >> GroupBy(1, nokey=True) >> Collect()
+    [[(3, 1)], [(2, 2)], [(1, 3)]]
+
     :param iterable iterable: Any iterable
     :param int|function keycol: Column index or key function.
     :param bool nokey: True: results will not contain keys for groups, only
@@ -640,6 +672,7 @@ def GroupBySorted(iterable, keycol=lambda x: x, nokey=False):
     See https://docs.python.org/2/library/itertools.html#itertools.groupby
     If iterable is not sorted use GroupBy but be aware that it stores all
     elements of the iterable in memory!
+    see also Chunk(), ChunkWhen(), ChunkBy()
 
     >>> from nutsflow import Collect, nut_sink
     
@@ -851,12 +884,12 @@ class Cache(Nut):
                     data >> expensive_op >> cache >> process(i) >> Consume()
 
 
-         .. code:: python
+        .. code:: python
 
             cache = Cache()
-                for _ in xrange(100)
-                    data >> expensive_op >> cache >> Collect()
-                cache.clear()
+            for _ in xrange(100)
+                data >> expensive_op >> cache >> Collect()
+            cache.clear()
 
         :param iterable iterable: Any iterable
         :param string storage: Currently only 'disk' mode.
